var NAVTREEINDEX4 =
{
"gphoto2-version_8c.html#a039629a84ef4c735b1124901438a7468":[2,0,2,18,0],
"gphoto2-version_8h.html":[2,0,1,9],
"gphoto2-version_8h.html#a039629a84ef4c735b1124901438a7468":[2,0,1,9,0],
"gphoto2-version_8h_source.html":[2,0,1,9],
"gphoto2-widget_8c.html":[2,0,2,19],
"gphoto2-widget_8c.html#a01706284163682eb459b045b651a2fcf":[2,0,2,19,17],
"gphoto2-widget_8c.html#a160a340c58e006a1a4de0ac77e02e136":[2,0,2,19,15],
"gphoto2-widget_8c.html#a20783a5aec3e3a7cd4c8ce3af7a92361":[2,0,2,19,16],
"gphoto2-widget_8c.html#a3017f318e2dadaf82d5d55140594bcdf":[2,0,2,19,9],
"gphoto2-widget_8c.html#a467afee62da7ca075c8b24c71cfd812a":[2,0,2,19,7],
"gphoto2-widget_8c.html#a4c4ea20c4d069c418399754822644174":[2,0,2,19,25],
"gphoto2-widget_8c.html#a582ecd400d10bb040b35c317c48cf638":[2,0,2,19,27],
"gphoto2-widget_8c.html#a58d57830ff9a7ce66b1b4b9faa93948a":[2,0,2,19,29],
"gphoto2-widget_8c.html#a5b80fa207622d0efc676c3219c6150eb":[2,0,2,19,23],
"gphoto2-widget_8c.html#a677590f6805dbf542d84cfe5a2718789":[2,0,2,19,31],
"gphoto2-widget_8c.html#a6e6287e13a841e6f7631d06d72c06237":[2,0,2,19,30],
"gphoto2-widget_8c.html#a7148abb7985c2d5d6310ef6b25d38256":[2,0,2,19,22],
"gphoto2-widget_8c.html#a7788e7259ec60c96088f1093670e6d8d":[2,0,2,19,20],
"gphoto2-widget_8c.html#a7a547c3a01c9ba10c8552187aca0a43f":[2,0,2,19,5],
"gphoto2-widget_8c.html#a7a9e6b495cbdf50dfeeb9f49f58e186e":[2,0,2,19,28],
"gphoto2-widget_8c.html#a8e84d6d4a4593ddef222d5246fa207ac":[2,0,2,19,21],
"gphoto2-widget_8c.html#a91689d5c09fdc861080faafaf10767a7":[2,0,2,19,13],
"gphoto2-widget_8c.html#aa46b3ea59abaafb0d83948fee80e57af":[2,0,2,19,8],
"gphoto2-widget_8c.html#ab3365698f977ba94534148d1df5eb9d8":[2,0,2,19,2],
"gphoto2-widget_8c.html#ac2407563a7f8c22de8df8d5009f0e4e1":[2,0,2,19,6],
"gphoto2-widget_8c.html#acc79e22647c2cda8c053da21e296f303":[2,0,2,19,14],
"gphoto2-widget_8c.html#ad15d33230a8a7b3d039d63bc5875c0ac":[2,0,2,19,10],
"gphoto2-widget_8c.html#ad90a0c554f7fcc61914fd54d4c612f34":[2,0,2,19,24],
"gphoto2-widget_8c.html#adaf6cc55afadae959d07adebecc85c65":[2,0,2,19,3],
"gphoto2-widget_8c.html#ae0bafe1d2115b44a8cc0ba1cc82f7560":[2,0,2,19,19],
"gphoto2-widget_8c.html#ae41c7eb76c0bb21770879ad8e1dc58b9":[2,0,2,19,1],
"gphoto2-widget_8c.html#aed8693ca96a9d877810329fc744323f1":[2,0,2,19,12],
"gphoto2-widget_8c.html#af3c1033ec2158a70fe987767b20d908a":[2,0,2,19,11],
"gphoto2-widget_8c.html#af769b52499b4e6f9134d345326f59897":[2,0,2,19,18],
"gphoto2-widget_8c.html#afa478d063b2470df8ba5ee29fc33b5bf":[2,0,2,19,4],
"gphoto2-widget_8c.html#afee1b0fb138aa4fd73c69b5f925e5afd":[2,0,2,19,26],
"gphoto2-widget_8h.html":[2,0,1,10],
"gphoto2-widget_8h.html#a01706284163682eb459b045b651a2fcf":[2,0,1,10,19],
"gphoto2-widget_8h.html#a160a340c58e006a1a4de0ac77e02e136":[2,0,1,10,17],
"gphoto2-widget_8h.html#a20783a5aec3e3a7cd4c8ce3af7a92361":[2,0,1,10,18],
"gphoto2-widget_8h.html#a3017f318e2dadaf82d5d55140594bcdf":[2,0,1,10,11],
"gphoto2-widget_8h.html#a467afee62da7ca075c8b24c71cfd812a":[2,0,1,10,9],
"gphoto2-widget_8h.html#a4c4ea20c4d069c418399754822644174":[2,0,1,10,27],
"gphoto2-widget_8h.html#a4ff53441fd74eb630a997d461220f781":[2,0,1,10,1],
"gphoto2-widget_8h.html#a582ecd400d10bb040b35c317c48cf638":[2,0,1,10,29],
"gphoto2-widget_8h.html#a58d57830ff9a7ce66b1b4b9faa93948a":[2,0,1,10,31],
"gphoto2-widget_8h.html#a5b80fa207622d0efc676c3219c6150eb":[2,0,1,10,25],
"gphoto2-widget_8h.html#a677590f6805dbf542d84cfe5a2718789":[2,0,1,10,33],
"gphoto2-widget_8h.html#a6e6287e13a841e6f7631d06d72c06237":[2,0,1,10,32],
"gphoto2-widget_8h.html#a7148abb7985c2d5d6310ef6b25d38256":[2,0,1,10,24],
"gphoto2-widget_8h.html#a76b1b482abd434a39ad607e9c72ee606":[2,0,1,10,30],
"gphoto2-widget_8h.html#a7788e7259ec60c96088f1093670e6d8d":[2,0,1,10,22],
"gphoto2-widget_8h.html#a7a547c3a01c9ba10c8552187aca0a43f":[2,0,1,10,7],
"gphoto2-widget_8h.html#a8c7e7c5b04d992022d9a821a0d3f9c30":[2,0,1,10,2],
"gphoto2-widget_8h.html#a8c7e7c5b04d992022d9a821a0d3f9c30a4da6bf6564c6535715ed7a51faf97d9e":[2,0,1,10,2,3],
"gphoto2-widget_8h.html#a8c7e7c5b04d992022d9a821a0d3f9c30a82006459973ca4f17729b99e2493242f":[2,0,1,10,2,7],
"gphoto2-widget_8h.html#a8c7e7c5b04d992022d9a821a0d3f9c30a82fd9cfdb47df56973dfebaa1ebb5356":[2,0,1,10,2,1],
"gphoto2-widget_8h.html#a8c7e7c5b04d992022d9a821a0d3f9c30a9d2fb92d970fe5a9d4abb2d11379f64f":[2,0,1,10,2,4],
"gphoto2-widget_8h.html#a8c7e7c5b04d992022d9a821a0d3f9c30aab0990bda50305e4314fa5d267ad8b2c":[2,0,1,10,2,5],
"gphoto2-widget_8h.html#a8c7e7c5b04d992022d9a821a0d3f9c30ab9247accefebceecdbebf6d8cbb7edf8":[2,0,1,10,2,8],
"gphoto2-widget_8h.html#a8c7e7c5b04d992022d9a821a0d3f9c30ac06d6140c294874ef251ba08834c506d":[2,0,1,10,2,0],
"gphoto2-widget_8h.html#a8c7e7c5b04d992022d9a821a0d3f9c30acdd16f51f1a6b63ef044a9fa6c9b851c":[2,0,1,10,2,6],
"gphoto2-widget_8h.html#a8c7e7c5b04d992022d9a821a0d3f9c30aed35470a4719ed91a2e163072112e835":[2,0,1,10,2,2],
"gphoto2-widget_8h.html#a8e84d6d4a4593ddef222d5246fa207ac":[2,0,1,10,23],
"gphoto2-widget_8h.html#a91689d5c09fdc861080faafaf10767a7":[2,0,1,10,15],
"gphoto2-widget_8h.html#aa46b3ea59abaafb0d83948fee80e57af":[2,0,1,10,10],
"gphoto2-widget_8h.html#ab3365698f977ba94534148d1df5eb9d8":[2,0,1,10,4],
"gphoto2-widget_8h.html#ac2407563a7f8c22de8df8d5009f0e4e1":[2,0,1,10,8],
"gphoto2-widget_8h.html#ac9da2516e7b6c1b10aa3c1656db72adc":[2,0,1,10,0],
"gphoto2-widget_8h.html#acc79e22647c2cda8c053da21e296f303":[2,0,1,10,16],
"gphoto2-widget_8h.html#ad15d33230a8a7b3d039d63bc5875c0ac":[2,0,1,10,12],
"gphoto2-widget_8h.html#ad90a0c554f7fcc61914fd54d4c612f34":[2,0,1,10,26],
"gphoto2-widget_8h.html#adaf6cc55afadae959d07adebecc85c65":[2,0,1,10,5],
"gphoto2-widget_8h.html#ae0bafe1d2115b44a8cc0ba1cc82f7560":[2,0,1,10,21],
"gphoto2-widget_8h.html#ae41c7eb76c0bb21770879ad8e1dc58b9":[2,0,1,10,3],
"gphoto2-widget_8h.html#aed8693ca96a9d877810329fc744323f1":[2,0,1,10,14],
"gphoto2-widget_8h.html#af3c1033ec2158a70fe987767b20d908a":[2,0,1,10,13],
"gphoto2-widget_8h.html#af769b52499b4e6f9134d345326f59897":[2,0,1,10,20],
"gphoto2-widget_8h.html#afa478d063b2470df8ba5ee29fc33b5bf":[2,0,1,10,6],
"gphoto2-widget_8h.html#afee1b0fb138aa4fd73c69b5f925e5afd":[2,0,1,10,28],
"gphoto2-widget_8h_source.html":[2,0,1,10],
"gphoto2_8h.html":[2,0,1,11],
"gphoto2_8h_source.html":[2,0,1,11],
"index.html":[],
"jpeg_8c.html":[2,0,2,20],
"jpeg_8c.html#a038573b7f439be589bd905b2e310490d":[2,0,2,20,11],
"jpeg_8c.html#a1061828e4e2cafb14086ac2bed47f80d":[2,0,2,20,0],
"jpeg_8c.html#a157a3d714ccab9eba11a83ab8c44ef2e":[2,0,2,20,7],
"jpeg_8c.html#a15c75310906f82a5922655361510dcf5":[2,0,2,20,24],
"jpeg_8c.html#a2a3b3ac76f7224d6e5f635f1a831e6c7":[2,0,2,20,8],
"jpeg_8c.html#a2a7832a90410c88f8f4d1f99ff64c461":[2,0,2,20,15],
"jpeg_8c.html#a2cc14f63e9eb5bac86a036771bfb1758":[2,0,2,20,12],
"jpeg_8c.html#a30e48d4e0366699fcd210b93a4c6a4f8":[2,0,2,20,26],
"jpeg_8c.html#a4aee2400e444196497aaf51b5bda674b":[2,0,2,20,17],
"jpeg_8c.html#a5bec69a612f0edb89186ecbc9cc8647b":[2,0,2,20,6],
"jpeg_8c.html#a621dd0efba334f3b4f8c76e131d18f1e":[2,0,2,20,22],
"jpeg_8c.html#a7f53c979d313bd96c6c179e51ffe9ad1":[2,0,2,20,3],
"jpeg_8c.html#a85517cf2a159ce5b1fd68b6ecde2a699":[2,0,2,20,2],
"jpeg_8c.html#a900e68ccf955cb2c1093a5521e33adb5":[2,0,2,20,18],
"jpeg_8c.html#a9fc326f857d0d4a8eb62180d9cfa6476":[2,0,2,20,4],
"jpeg_8c.html#aa09238d43527626cac819e8ef6a36d54":[2,0,2,20,19],
"jpeg_8c.html#aa921b801f3dc15f52826f9a8b43cb4e9":[2,0,2,20,10],
"jpeg_8c.html#ab317c73e51fb8a68f86165ac831f7b8c":[2,0,2,20,1],
"jpeg_8c.html#ab9d785ab5c19c852cc9d9d3cf84c64ff":[2,0,2,20,20],
"jpeg_8c.html#ac42e2c47c8ddd27a735d598aecb6270e":[2,0,2,20,14],
"jpeg_8c.html#acd4139fff7d6df4f514c19439a0699e6":[2,0,2,20,16],
"jpeg_8c.html#ad12833761f2113dc7e34b802ee4b6217":[2,0,2,20,25],
"jpeg_8c.html#ae08d9f698f1bdfc5b7a4ce0193fd177f":[2,0,2,20,9],
"jpeg_8c.html#ae61037acbc754622dffb58feca3cea03":[2,0,2,20,23],
"jpeg_8c.html#aee946402a45cc98e3b6489b52ae64988":[2,0,2,20,5],
"jpeg_8c.html#afbeff88ccf50318f6063c96a1468ed20":[2,0,2,20,13],
"jpeg_8c.html#afc52ca20abf3220442afe60db8b937b2":[2,0,2,20,21],
"jpeg_8h.html":[2,0,2,21],
"jpeg_8h.html#a038573b7f439be589bd905b2e310490d":[2,0,2,21,13],
"jpeg_8h.html#a157a3d714ccab9eba11a83ab8c44ef2e":[2,0,2,21,9],
"jpeg_8h.html#a23992c28c13fcf5ed0906e7bb8cefa60":[2,0,2,21,3],
"jpeg_8h.html#a2a3b3ac76f7224d6e5f635f1a831e6c7":[2,0,2,21,10],
"jpeg_8h.html#a2a7832a90410c88f8f4d1f99ff64c461":[2,0,2,21,17],
"jpeg_8h.html#a2cc14f63e9eb5bac86a036771bfb1758":[2,0,2,21,14],
"jpeg_8h.html#a3b490d263fb18683ec488cb84c524b61":[2,0,2,21,4],
"jpeg_8h.html#a4aee2400e444196497aaf51b5bda674b":[2,0,2,21,19],
"jpeg_8h.html#a4f97cb61c318d39f00ca3962623c310d":[2,0,2,21,21],
"jpeg_8h.html#a5608ad9c74e0d5fd5b5662244c8c70fb":[2,0,2,21,18],
"jpeg_8h.html#a5bec69a612f0edb89186ecbc9cc8647b":[2,0,2,21,8],
"jpeg_8h.html#a621dd0efba334f3b4f8c76e131d18f1e":[2,0,2,21,24],
"jpeg_8h.html#a8229fcb1c7292fb6da9cbddea14719a4":[2,0,2,21,26],
"jpeg_8h.html#a900e68ccf955cb2c1093a5521e33adb5":[2,0,2,21,20],
"jpeg_8h.html#a9fc326f857d0d4a8eb62180d9cfa6476":[2,0,2,21,6],
"jpeg_8h.html#aa921b801f3dc15f52826f9a8b43cb4e9":[2,0,2,21,12],
"jpeg_8h.html#ab9d785ab5c19c852cc9d9d3cf84c64ff":[2,0,2,21,22],
"jpeg_8h.html#ac42e2c47c8ddd27a735d598aecb6270e":[2,0,2,21,16],
"jpeg_8h.html#ad06d178d14aae0033c1c51e5728afbdd":[2,0,2,21,5],
"jpeg_8h.html#ad06d178d14aae0033c1c51e5728afbdda2261bb2d4859330c24c587da1d8118e4":[2,0,2,21,5,0],
"jpeg_8h.html#ad06d178d14aae0033c1c51e5728afbdda531a38469ca8aaa94805669a7b1d7721":[2,0,2,21,5,7],
"jpeg_8h.html#ad06d178d14aae0033c1c51e5728afbdda5b979376aad7a437eaef22ef62a752ba":[2,0,2,21,5,2],
"jpeg_8h.html#ad06d178d14aae0033c1c51e5728afbdda6fbf69f957096a5a30c7a8a18cd59b14":[2,0,2,21,5,6],
"jpeg_8h.html#ad06d178d14aae0033c1c51e5728afbdda76e6ea930adad8ac53b7b37ddf44071e":[2,0,2,21,5,4],
"jpeg_8h.html#ad06d178d14aae0033c1c51e5728afbdda86ce7335618ccd615eb9836d6d1c5a63":[2,0,2,21,5,1],
"jpeg_8h.html#ad06d178d14aae0033c1c51e5728afbddac5c308abd323898ed35b2eac42237280":[2,0,2,21,5,5],
"jpeg_8h.html#ad06d178d14aae0033c1c51e5728afbddae64f063f5f4a0d160ce5b8c2e4fb6b62":[2,0,2,21,5,3],
"jpeg_8h.html#add022e5f235487028fc7a862de4459ac":[2,0,2,21,2],
"jpeg_8h.html#ae08d9f698f1bdfc5b7a4ce0193fd177f":[2,0,2,21,11],
"jpeg_8h.html#ae61037acbc754622dffb58feca3cea03":[2,0,2,21,25],
"jpeg_8h.html#aee946402a45cc98e3b6489b52ae64988":[2,0,2,21,7],
"jpeg_8h.html#afbeff88ccf50318f6063c96a1468ed20":[2,0,2,21,15],
"jpeg_8h.html#afc52ca20abf3220442afe60db8b937b2":[2,0,2,21,23],
"jpeg_8h_source.html":[2,0,2,21],
"pages.html":[],
"structCameraAbilities.html":[1,0,29],
"structCameraAbilities.html#a151938cff5c0e513f1f29d1af5b85d8e":[1,0,29,13],
"structCameraAbilities.html#a1b53da8592bdeaacf418b66dde09afc8":[1,0,29,11],
"structCameraAbilities.html#a2563f727188e388a0d1b56ee602b4bc8":[1,0,29,4],
"structCameraAbilities.html#a3ebec7be1e6528e451e5fcdb989e5124":[1,0,29,21],
"structCameraAbilities.html#a444494b9920cba8fa1d1bb7ed0b06261":[1,0,29,5],
"structCameraAbilities.html#a4451195881be4aa7e56933dc354e0430":[1,0,29,7],
"structCameraAbilities.html#a462953e49f54fe313439a7aafe163428":[1,0,29,17],
"structCameraAbilities.html#a499af16abc8a7b8ab1498b86589566f7":[1,0,29,14],
"structCameraAbilities.html#a4a8bb77e122df4c2d1dd0b3a4e06aaab":[1,0,29,19],
"structCameraAbilities.html#a6ce8f70b23920da2ec6fd5575147dde9":[1,0,29,15],
"structCameraAbilities.html#a6efea4276c434c519b6b2e7bbe4199a5":[1,0,29,12],
"structCameraAbilities.html#a85f035d23af22a22dcbcb6179461a9b2":[1,0,29,16],
"structCameraAbilities.html#a92aea1659935e3026244c9bfa52b47e3":[1,0,29,10],
"structCameraAbilities.html#aa69d4c1cd5c1b78412ecdf64f1ee12b9":[1,0,29,2],
"structCameraAbilities.html#aac03205ae0594aa3f4c9950cc07d4d2a":[1,0,29,0],
"structCameraAbilities.html#ab848badc7ca4167ceac12163efd6e312":[1,0,29,3],
"structCameraAbilities.html#ac4def437fda197bdae93dc8adebc7c9a":[1,0,29,9],
"structCameraAbilities.html#ad567d6fc8fe165ff168a7873b4ff06cf":[1,0,29,18],
"structCameraAbilities.html#ae138b41e1bfec18f9f9b80e46b625ea2":[1,0,29,6],
"structCameraAbilities.html#ae332f74bb4f6b3f8b88db3f625bcc0d8":[1,0,29,20],
"structCameraAbilities.html#aebc9344eb8776f612ae545959c247611":[1,0,29,8],
"structCameraAbilities.html#af914e0f9fbdce526f5c8dd647d25345c":[1,0,29,1],
"structCameraFile.html":[1,0,30],
"structCameraFilePath.html":[1,0,31],
"structCameraFilePath.html#a26f1902eac5f6088334edbd1351e7ec9":[1,0,31,1],
"structCameraFilePath.html#a576f3bdaaf2905795120cb4a8b274364":[1,0,31,0],
"structCameraText.html":[1,0,32],
"structCameraText.html#af37011bda3c08a5b85d996a8a96a1175":[1,0,32,0],
"structExifData.html":[1,0,35],
"structExifData.html#a0855a0f999ff6318fc6164eac9558739":[1,0,35,3],
"structExifData.html#a507ec464eb69af9dcf6643529474fe25":[1,0,35,4],
"structExifData.html#a777d4a75a71a323d679e36040eefe949":[1,0,35,5],
"structExifData.html#a817025910c9a21ad11e36cc6291f74d7":[1,0,35,1],
"structExifData.html#aa1ffe358b9a4d06c3e6d77ad60bfed7f":[1,0,35,6],
"structExifData.html#aca6f46963e0f2c21eb0a0947d9a5cbf9":[1,0,35,0],
"structExifData.html#afea5ad4801e3718debc333caf6e4a410":[1,0,35,2],
"structLogFunc.html":[1,0,38],
"structLogFunc.html#a068941612eb97ecd67e9f215079da7b7":[1,0,38,2],
"structLogFunc.html#a9924d784a044385a061cf38ba69acfa1":[1,0,38,0],
"structLogFunc.html#a9dc0273791c4d020e92867460e6fb605":[1,0,38,3],
"structLogFunc.html#adfa343a5175adcb7a670caf959615b86":[1,0,38,1],
"structSetting.html":[1,0,39],
"structSetting.html#a13b7fdbd033bf614f735995debcc0bfe":[1,0,39,2],
"structSetting.html#a48642590d108a71ef0f4a4b243d0556b":[1,0,39,1],
"structSetting.html#a4946f76797007123198a74dbe3ae1a01":[1,0,39,0],
"struct__Camera.html":[1,0,0],
"struct__Camera.html#a4e8cee96ef5ef4f271c866d8d2c0ce9d":[1,0,0,0],
"struct__Camera.html#a640193a6f18e834a87e71bc9dd3fedd2":[1,0,0,3],
"struct__Camera.html#a7cf3ccebb4c551420ec3da8e19c64bb8":[1,0,0,4],
"struct__Camera.html#aa1e698a6fa5414e25381db64c7471e40":[1,0,0,2],
"struct__Camera.html#af55d6e519c6b49eb11e518c419b1627f":[1,0,0,1],
"struct__CameraAbilitiesList.html":[1,0,1],
"struct__CameraAbilitiesList.html#a3a18bfd44cf3ae22ebea7587153debb9":[1,0,1,0],
"struct__CameraAbilitiesList.html#ad57e34bd38b93bcdaf2b47629105531d":[1,0,1,1],
"struct__CameraFile.html":[1,0,2],
"struct__CameraFile.html#a05fa8fdab784c185cabe2485c7820875":[1,0,2,10],
"struct__CameraFile.html#a0755a99b8300daa39f2d813172e02350":[1,0,2,5],
"struct__CameraFile.html#a19e830d08aacdea4d10c1f0120ee2e6d":[1,0,2,7],
"struct__CameraFile.html#a2afa59a883cafab4da1c5aded0a7aab7":[1,0,2,6],
"struct__CameraFile.html#a478c42e8553dcfc59353586f18f9d11d":[1,0,2,2],
"struct__CameraFile.html#a66f54c5f0f56c6ef8018f20af9d3522f":[1,0,2,4],
"struct__CameraFile.html#a7162aa1c20c89a5a50b0c7b74462d5a7":[1,0,2,9],
"struct__CameraFile.html#abb383f3d29d3ec095e099f6cc02ee3b2":[1,0,2,8],
"struct__CameraFile.html#ac908b94c4cf6aa32411a92139f63ffb9":[1,0,2,1],
"struct__CameraFile.html#ae2356552d82970aa6dc283c3d6376ec3":[1,0,2,0],
"struct__CameraFile.html#af4d719b672fb67028a17b8f8fc0a0409":[1,0,2,3],
"struct__CameraFileHandler.html":[1,0,3],
"struct__CameraFileHandler.html#a5bbba5d19117be4affa56639088025cc":[1,0,3,2],
"struct__CameraFileHandler.html#aaa08112442b99b25e1c230f61a72decc":[1,0,3,1],
"struct__CameraFileHandler.html#ad2e1e6423213516de8194fcfd3ef4d0a":[1,0,3,0],
"struct__CameraFileInfo.html":[1,0,4],
"struct__CameraFileInfo.html#a1179620523bf1e56b47bcc7050b2cd76":[1,0,4,2],
"struct__CameraFileInfo.html#a37f70742bfcbfae4e06e6bfcc235a772":[1,0,4,0],
"struct__CameraFileInfo.html#af6901a6566b7c9033745fd7b2d73a053":[1,0,4,1],
"struct__CameraFileInfoAudio.html":[1,0,5],
"struct__CameraFileInfoAudio.html#a190a2dd6da89b72e4df72ee5c2014230":[1,0,5,2],
"struct__CameraFileInfoAudio.html#a33ea53cadff0dccbf6ec3c3f466a99c9":[1,0,5,1],
"struct__CameraFileInfoAudio.html#a7c3eaef785f49622bd15f3b1c51b1b95":[1,0,5,3],
"struct__CameraFileInfoAudio.html#aa929345276953d49d7be754bcd4f478a":[1,0,5,0],
"struct__CameraFileInfoFile.html":[1,0,6],
"struct__CameraFileInfoFile.html#a363772961bf2fc2e90c27120849e8010":[1,0,6,5],
"struct__CameraFileInfoFile.html#a5e3516f901c3f3a1f94a4ee8bda370c2":[1,0,6,0],
"struct__CameraFileInfoFile.html#a6f4e10ef142ae1126784ff1f826a78fe":[1,0,6,3],
"struct__CameraFileInfoFile.html#a78631442027c5f7134498ba323891ed3":[1,0,6,4],
"struct__CameraFileInfoFile.html#a8b798b3031a1998be77beb5ba547cb62":[1,0,6,6],
"struct__CameraFileInfoFile.html#a8cc5d010274aec1dfc222f1649133e2f":[1,0,6,7],
"struct__CameraFileInfoFile.html#ae7acce7dab662a7dfb088602176ac20b":[1,0,6,2],
"struct__CameraFileInfoFile.html#af076fe6da9612a0167acf489c40f31e8":[1,0,6,1],
"struct__CameraFileInfoPreview.html":[1,0,7],
"struct__CameraFileInfoPreview.html#a08eb4d953d2c9f4f7e8ce54223bb8ea9":[1,0,7,3],
"struct__CameraFileInfoPreview.html#a12d6115703a502a24cd5b193b75d666a":[1,0,7,5],
"struct__CameraFileInfoPreview.html#a2cc5f80f66aa90d7c276df9ecd530490":[1,0,7,1],
"struct__CameraFileInfoPreview.html#a42e378c8d0668052b39c0cca22382dd7":[1,0,7,4],
"struct__CameraFileInfoPreview.html#a872f4d1625b0008c625138f33ef3e4cb":[1,0,7,0],
"struct__CameraFileInfoPreview.html#a9a3b70779dc8cea4d520b9349bee6ba4":[1,0,7,2],
"struct__CameraFilesystem.html":[1,0,8],
"struct__CameraFilesystem.html#a1df04156f0ffe145f2e9d99eea9641ee":[1,0,8,13],
"struct__CameraFilesystem.html#a2f676eede09ea213a0ef7e8711d6ddf3":[1,0,8,5],
"struct__CameraFilesystem.html#a31e9fa7b813074658672a512b683a334":[1,0,8,1],
"struct__CameraFilesystem.html#a32c4b277105e1a86ade9700dbc1cf891":[1,0,8,4],
"struct__CameraFilesystem.html#a38fcb7940178fa609cd62b8aa9ea5c29":[1,0,8,10]
};
